@@ -37,20 +37,6 @@
 #include <gconf/gconf-internals.h>
 #include "xml-entry.h"
 
-/* Quick hack so I can mark strings */
-
-#ifdef _ 
-#warning "_ already defined"
-#else
-#define _(x) x
-#endif
-
-#ifdef N_ 
-#warning "N_ already defined"
-#else
-#define N_(x) x
-#endif
-
 /* This makes hash table safer when debugging */
 #ifndef GCONF_ENABLE_DEBUG
 #define safe_g_hash_table_insert g_hash_table_insert
@@ -91,7 +77,7 @@ struct _Dir {
 };
 
 static void
-dir_load_doc(Dir* d, GConfError** err);
+dir_load_doc(Dir* d, GError** err);
 
 static Entry* dir_make_new_entry(Dir* d, const gchar* relative_key);
 
@@ -142,7 +128,7 @@ dir_new(const gchar  *keyname,
   d = dir_blank(keyname);
 
   /* sync with dir_load() */
-  d->fs_dirname = gconf_concat_key_and_dir(xml_root_dir, keyname);
+  d->fs_dirname = gconf_concat_dir_and_key(xml_root_dir, keyname);
   d->xml_filename =  g_strconcat(d->fs_dirname, "/%gconf.xml", NULL);
   d->root_dir_len = strlen(xml_root_dir);
 
@@ -153,7 +139,7 @@ dir_new(const gchar  *keyname,
 }
 
 Dir*
-dir_load        (const gchar* key, const gchar* xml_root_dir, GConfError** err)
+dir_load        (const gchar* key, const gchar* xml_root_dir, GError** err)
 {
   Dir* d;
   gchar* fs_dirname;
@@ -163,7 +149,7 @@ dir_load        (const gchar* key, const gchar* xml_root_dir, GConfError** err)
   
   g_return_val_if_fail(gconf_valid_key(key, NULL), NULL);
   
-  fs_dirname = gconf_concat_key_and_dir(xml_root_dir, key);
+  fs_dirname = gconf_concat_dir_and_key(xml_root_dir, key);
   xml_filename = g_strconcat(fs_dirname, "/%gconf.xml", NULL);
 
   {
@@ -200,7 +186,7 @@ dir_load        (const gchar* key, const gchar* xml_root_dir, GConfError** err)
     else
       {
         dir_mode = mode_t_to_mode(s.st_mode);
-        file_mode &= ~0111; /* turn off search bits */
+        file_mode = dir_mode & ~0111; /* turn off search bits */
       }
   }
 
@@ -248,11 +234,11 @@ static gboolean
 create_fs_dir(const gchar* dir, const gchar* xml_filename,
               guint root_dir_len,
               guint dir_mode, guint file_mode,
-              GConfError** err);
+              GError** err);
 
 gboolean
 dir_ensure_exists (Dir* d,
-                   GConfError** err)
+                   GError** err)
 {
   if (!create_fs_dir(d->fs_dirname, d->xml_filename, d->root_dir_len,
                      d->dir_mode, d->file_mode,
@@ -283,7 +269,7 @@ dir_sync_pending    (Dir          *d)
 }
 
 gboolean
-dir_sync        (Dir* d, GConfError** err)
+dir_sync        (Dir* d, GError** err)
 {
   gboolean retval = TRUE;
   
@@ -416,7 +402,7 @@ dir_sync        (Dir* d, GConfError** err)
 
 void
 dir_set_value   (Dir* d, const gchar* relative_key,
-                 GConfValue* value, GConfError** err)
+                 GConfValue* value, GError** err)
 {
   Entry* e;
   
@@ -455,7 +441,7 @@ dir_get_value   (Dir* d,
                  const gchar* relative_key,
                  const gchar** locales,
                  gchar** schema_name,
-                 GConfError** err)
+                 GError** err)
 {
   Entry* e;
 
@@ -483,7 +469,7 @@ dir_get_value   (Dir* d,
 
       g_assert(e != NULL);
 
-      val = entry_get_value(e, locales, err);
+      val = entry_get_value (e, locales, err);
 
       /* Fill schema name if value is NULL because we might be
          interested in the default value of the key in that case. */
@@ -508,7 +494,7 @@ dir_get_name        (Dir          *d)
 }
 
 GConfMetaInfo*
-dir_get_metainfo(Dir* d, const gchar* relative_key, GConfError** err)
+dir_get_metainfo(Dir* d, const gchar* relative_key, GError** err)
 {
   Entry* e;
   
@@ -533,7 +519,7 @@ dir_get_metainfo(Dir* d, const gchar* relative_key, GConfError** err)
 
 void
 dir_unset_value (Dir* d, const gchar* relative_key,
-                 const gchar* locale, GConfError** err)
+                 const gchar* locale, GError** err)
 {
   Entry* e;
   
@@ -593,31 +579,31 @@ listify_foreach(const gchar* key, Entry* e, ListifyData* ld)
 {
   GConfValue* val;
   GConfEntry* entry;
-  GConfError* error = NULL;
+  GError* error = NULL;
   
-  val = entry_get_value(e, ld->locales, &error);
+  val = entry_get_value (e, ld->locales, &error);
 
   if (error != NULL)
     {
-      g_assert(val == NULL);
-      gconf_error_destroy(error);
+      g_assert (val == NULL);
+      g_error_free (error);
       return;
     }
   
-  entry = gconf_entry_new_nocopy(g_strdup(key),
-                                 val ? gconf_value_copy(val) : NULL);
+  entry = gconf_entry_new_nocopy (g_strdup(key),
+                                  val ? gconf_value_copy(val) : NULL);
   
   if (val == NULL &&
-      entry_get_schema_name(e))
+      entry_get_schema_name (e))
     {
-      gconf_entry_set_schema_name(entry, entry_get_schema_name(e));
+      gconf_entry_set_schema_name (entry, entry_get_schema_name (e));
     }
   
   ld->list = g_slist_prepend(ld->list, entry);
 }
 
 GSList*
-dir_all_entries (Dir* d, const gchar** locales, GConfError** err)
+dir_all_entries (Dir* d, const gchar** locales, GError** err)
 {
   ListifyData ld;
   
@@ -641,7 +627,7 @@ dir_all_entries (Dir* d, const gchar** locales, GConfError** err)
 }
 
 GSList*
-dir_all_subdirs (Dir* d, GConfError** err)
+dir_all_subdirs (Dir* d, GError** err)
 {
   DIR* dp;
   struct dirent* dent;
@@ -705,6 +691,8 @@ dir_all_subdirs (Dir* d, GConfError** err)
   /* if this fails, we really can't do a thing about it
      and it's not a meaningful error */
   closedir(dp);
+
+  g_free (fullpath);
   
   return retval;
 }
@@ -713,7 +701,7 @@ void
 dir_set_schema  (Dir* d,
                  const gchar* relative_key,
                  const gchar* schema_key,
-                 GConfError** err)
+                 GError** err)
 {
   Entry* e;
 
@@ -776,7 +764,7 @@ static void
 dir_fill_cache_from_doc(Dir* d);
 
 static void
-dir_load_doc(Dir* d, GConfError** err)
+dir_load_doc(Dir* d, GError** err)
 {
   gboolean xml_already_exists = TRUE;
   gboolean need_backup = FALSE;
@@ -987,7 +975,7 @@ dir_fill_cache_from_doc(Dir* d)
 static gboolean
 create_fs_dir(const gchar* dir, const gchar* xml_filename,
               guint root_dir_len, guint dir_mode, guint file_mode,
-              GConfError** err)
+              GError** err)
 {
   g_return_val_if_fail(xml_filename != NULL, FALSE);
   
