@@ -41,7 +41,7 @@ struct _GConfSource {
 
 typedef enum {
   /* These are an optimization to avoid calls to
-   * the writeable/readable methods in the backend
+   * the writable/readable methods in the backend
    * vtable
    */
   GCONF_SOURCE_ALL_WRITEABLE = 1 << 0,
@@ -51,9 +51,9 @@ typedef enum {
 } GConfSourceFlags;
 
 GConfSource*  gconf_resolve_address         (const gchar* address,
-                                             GConfError** err);
+                                             GError** err);
 
-void          gconf_source_destroy          (GConfSource* source);
+void          gconf_source_free          (GConfSource* source);
 
 /* This is the actual thing we want to talk to, the stack of sources */
 typedef struct _GConfSources GConfSources;
@@ -67,53 +67,55 @@ struct _GConfSources {
    returns NULL but may set the error if some addresses weren't
    resolved and may contain no sources.  */
 GConfSources* gconf_sources_new_from_addresses (const gchar **addresses,
-                                                GConfError   **err);
+                                                GError   **err);
 GConfSources* gconf_sources_new_from_source    (GConfSource   *source);
-void          gconf_sources_destroy            (GConfSources  *sources);
+void          gconf_sources_free            (GConfSources  *sources);
 void          gconf_sources_clear_cache        (GConfSources  *sources);
 GConfValue*   gconf_sources_query_value        (GConfSources  *sources,
                                                 const gchar   *key,
                                                 const gchar  **locales,
                                                 gboolean       use_schema_default,
                                                 gboolean      *value_is_default,
-                                                GConfError   **err);
+                                                gboolean      *value_is_writable,
+                                                GError   **err);
 void          gconf_sources_set_value          (GConfSources  *sources,
                                                 const gchar   *key,
                                                 GConfValue    *value,
-                                                GConfError   **err);
+                                                GError   **err);
 void          gconf_sources_unset_value        (GConfSources  *sources,
                                                 const gchar   *key,
                                                 const gchar   *locale,
-                                                GConfError   **err);
+                                                GError   **err);
 GSList*       gconf_sources_all_entries        (GConfSources  *sources,
                                                 const gchar   *dir,
                                                 const gchar  **locales,
-                                                GConfError   **err);
+                                                GError   **err);
 GSList*       gconf_sources_all_dirs           (GConfSources  *sources,
                                                 const gchar   *dir,
-                                                GConfError   **err);
+                                                GError   **err);
 gboolean      gconf_sources_dir_exists         (GConfSources  *sources,
                                                 const gchar   *dir,
-                                                GConfError   **err);
+                                                GError   **err);
 void          gconf_sources_remove_dir         (GConfSources  *sources,
                                                 const gchar   *dir,
-                                                GConfError   **err);
+                                                GError   **err);
 void          gconf_sources_set_schema         (GConfSources  *sources,
                                                 const gchar   *key,
                                                 const gchar   *schema_key,
-                                                GConfError   **err);
+                                                GError   **err);
 gboolean      gconf_sources_sync_all           (GConfSources  *sources,
-                                                GConfError   **err);
+                                                GError   **err);
 
 
 GConfMetaInfo*gconf_sources_query_metainfo     (GConfSources* sources,
                                                 const gchar* key,
-                                                GConfError** err);
+                                                GError** err);
 
 GConfValue*   gconf_sources_query_default_value(GConfSources* sources,
                                                 const gchar* key,
                                                 const gchar** locales,
-                                                GConfError** err);
+                                                gboolean* is_writable,
+                                                GError** err);
 
 #endif
 
