@@ -73,56 +73,56 @@ some_strings[] = {
   "sjdflkjg;kljklj",
   "hello this is a string with spaces and \t\t\t\ttabs",
   "hello this\nstring\nhas\nnewlines\n   \t\t\t\t\t\ttabs and spaces  \n",
-  "<?xml version=\"1.0\"?>
-<gmr:Workbook xmlns:gmr=\"http://www.gnome.org/gnumeric/\">
-  <gmr:Style HAlign=\"1\" VAlign=\"1\" Fit=\"0\" Orient=\"1\" Shade=\"0\" Format=\"#,##0_);[red](#,##0)\">
-    <gmr:Font Unit=\"14\" NAME=\"FontDef1\">-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*</gmr:Font>
-  </gmr:Style>
-  <gmr:Geometry Width=\"610\" Height=\"418\"/>
-  <gmr:Sheets>
-    <gmr:Sheet>
-      <gmr:Name>Sheet 0</gmr:Name>
-      <gmr:MaxCol>6</gmr:MaxCol>
-      <gmr:MaxRow>14</gmr:MaxRow>
-      <gmr:Zoom>1.000000</gmr:Zoom>
-      <gmr:Cols>
-        <gmr:ColInfo No=\"0\" Unit=\"97\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:ColInfo No=\"1\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:ColInfo No=\"2\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:ColInfo No=\"3\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:ColInfo No=\"6\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-      </gmr:Cols>
-      <gmr:Rows>
-        <gmr:RowInfo No=\"0\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"1\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"2\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"3\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"4\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"5\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"6\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"7\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"8\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"9\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"10\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"11\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"12\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"13\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-        <gmr:RowInfo No=\"14\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>
-      </gmr:Rows>
-      <gmr:Objects>
-        <gmr:Ellipse Pattern=\"0\" Width=\"1\" Color=\"black\">
-          <gmr:Points>(258.000000 320.000000)(356.000000 356.000000)</gmr:Points>
-        </gmr:Ellipse>
-        <gmr:Arrow Width=\"1\" Color=\"black\">
-          <gmr:Points>(500.000000 131.000000)(332.000000 320.000000)</gmr:Points>
-        </gmr:Arrow>
-      </gmr:Objects>
-      <gmr:Cells>
-        <gmr:Cell Col=\"3\" Row=\"1\">
-          <gmr:Style HAlign=\"1\" VAlign=\"1\" Fit=\"0\" Orient=\"1\" Shade=\"0\" Format=\"#,##0_);[red](#,##0)\">
-            <gmr:Font Unit=\"14\" NAME=\"FontDef2\">-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*</gmr:Font>
-          </gmr:Style>
-          <gmr:Content>500</gmr:Content>",
+  "<?xml version=\"1.0\"?>"
+	"<gmr:Workbook xmlns:gmr=\"http://www.gnome.org/gnumeric/\">"
+	  "<gmr:Style HAlign=\"1\" VAlign=\"1\" Fit=\"0\" Orient=\"1\" Shade=\"0\" Format=\"#,##0_);[red](#,##0)\">"
+	    "<gmr:Font Unit=\"14\" NAME=\"FontDef1\">-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*</gmr:Font>"
+	  "</gmr:Style>"
+	  "<gmr:Geometry Width=\"610\" Height=\"418\"/>"
+	  "<gmr:Sheets>"
+	    "<gmr:Sheet>"
+	      "<gmr:Name>Sheet 0</gmr:Name>"
+	      "<gmr:MaxCol>6</gmr:MaxCol>"
+	      "<gmr:MaxRow>14</gmr:MaxRow>"
+	      "<gmr:Zoom>1.000000</gmr:Zoom>"
+	      "<gmr:Cols>"
+		"<gmr:ColInfo No=\"0\" Unit=\"97\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:ColInfo No=\"1\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:ColInfo No=\"2\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:ColInfo No=\"3\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:ColInfo No=\"6\" Unit=\"80\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+	      "</gmr:Cols>"
+	      "<gmr:Rows>"
+		"<gmr:RowInfo No=\"0\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"1\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"2\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"3\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"4\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"5\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"6\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"7\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"8\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"9\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"10\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"11\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"12\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"13\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+		"<gmr:RowInfo No=\"14\" Unit=\"20\" MarginA=\"1\" MarginB=\"1\" HardSize=\"0\"/>"
+	      "</gmr:Rows>"
+	      "<gmr:Objects>"
+		"<gmr:Ellipse Pattern=\"0\" Width=\"1\" Color=\"black\">"
+		  "<gmr:Points>(258.000000 320.000000)(356.000000 356.000000)</gmr:Points>"
+		"</gmr:Ellipse>"
+		"<gmr:Arrow Width=\"1\" Color=\"black\">"
+		  "<gmr:Points>(500.000000 131.000000)(332.000000 320.000000)</gmr:Points>"
+		"</gmr:Arrow>"
+	      "</gmr:Objects>"
+	      "<gmr:Cells>"
+		"<gmr:Cell Col=\"3\" Row=\"1\">"
+		  "<gmr:Style HAlign=\"1\" VAlign=\"1\" Fit=\"0\" Orient=\"1\" Shade=\"0\" Format=\"#,##0_);[red](#,##0)\">"
+		    "<gmr:Font Unit=\"14\" NAME=\"FontDef2\">-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*</gmr:Font>"
+		  "</gmr:Style>"
+          "<gmr:Content>500</gmr:Content>",
 
   NULL
 };
@@ -261,7 +261,7 @@ check_string_storage(GConfEngine* conf)
               g_error_free(err);
               err = NULL;
             }
-          else
+          else if (gotten)
             {
               check (strcmp(gotten, *valp) == 0, "string set/get pair: `%s' set, `%s' got",
                      *valp, gotten);
@@ -537,6 +537,32 @@ check_int_storage(GConfEngine* conf)
       
       ++keyp;
     }
+  keyp = keys;
+  while (*keyp)
+    {
+          gint gotten;
+      i = n_ints-1;
+          
+              gotten = gconf_engine_get_int(conf, *keyp, &err);
+
+              if (err != NULL)
+                {
+                  check(gotten == 0.0, "0.0 not returned though there was an error");
+
+                  fprintf(stderr, "Failed to get key `%s': %s\n",
+                          *keyp, err->message);
+                  g_error_free(err);
+                  err = NULL;
+                }
+              else
+                {
+                  check (ints[i] == gotten,
+                         "int set/get pair: `%d' set, `%d' got",
+                         ints[i], gotten);
+
+                }
+      ++keyp;
+    }
 
   /* Now invert the loop and see if that causes problems */
 
